import { AfterViewInit, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor, NgControl } from '@angular/forms';
import { IControlValidation } from '../../models/chr-validators/base-validator';
import { Subscription } from 'rxjs';
import { InputType } from '../../models/controls';
import * as i0 from "@angular/core";
export declare class ChrBaseInputComponent implements OnInit, ControlValueAccessor, AfterViewInit, OnDestroy {
    /**
     * The label that will be shown to the user for this input.
     */
    label: string | null;
    /**
     * The type of the input. The BaseInput class is designed to be used for the basic text/number/password/hidden types. Any other kind of input would probably benefit of a custom component inheriting BaseInput.
     */
    type: InputType;
    /**
     * The id of the input.
     */
    id: string | null;
    /**
     * The name of the input. It's the model's property name or the key that will be set to the value object
     */
    name: string | null;
    private _value;
    get value(): any | null;
    set value(value: any | null);
    private valueSubject;
    private valueSubscription;
    /**
     * The value change event. This will be triggered both by onChange and by onValueChange (they technically should not be fired together as onValueChange ends up calling onChange)
     */
    valueChanges: EventEmitter<any>;
    /**
     * Whether or not the input is required
     */
    protected required: boolean;
    /**
     * Span that will be shown under the input
     */
    span: string | null;
    /**
     * Name of the material icon that will be displayed
     */
    icon: string | null;
    /**
     * A callback function that will be triggered on the input's icon click with the current value of the input
     */
    iconCallback: ((value: any) => string) | null;
    /**
     * Whether or not the icon's callback is enabled
     */
    iconCallbackDisabled: boolean;
    /**
     * Tooltip that will be displayed when hovering the input's icon
     */
    iconTooltip: string | null;
    /**
     * Tooltip that will be displayed on hover
     */
    tooltip: string | null;
    /**
     * Debounce time that will be used by the input before throwing the new value event
     */
    debounceTime?: number | null;
    /**
     * Validations that will be evaluated for the input. In the case of custom validator function, the return object needs to contain a key with the 'rule' and it's value needs to be 'true'
     */
    validations: IControlValidation[];
    /**
     * Indicates whether or not this input is being used outside a ReactiveForm. Default is false. If this is false, the input will create it's own FormControl as to enable it's complex behaviors
     */
    standalone: boolean;
    /**
     * Indicates whether or not this input should try catching the focus on page load
     */
    autofocus: boolean;
    /**
     * Indicates whether or not this input should convert the file to base64 for it to be sent as part of the object.
     * If this is false, the file won't be converted and will be sent as part as the regular form process.
     * Default is true to allow full JS manipulation of files et upload progress report.
     */
    base64: boolean;
    private _disabled;
    /**
     * Getter and setter that allow the control of the FormControl's state from the template
     */
    get disabled(): boolean;
    set disabled(value: boolean);
    /**
     * Whether or not the input starts as disabled. This can then be changed through the form control.
     */
    isDisabled: boolean;
    /**
     * Array of string representing the input's siblings' FormControl's name. This will be used to trigger the validity of the siblings when this input's value changes
     */
    siblings: string[];
    onChange: any;
    onTouch: any;
    /**
     * Whether or not the input is touched
     */
    isTouched: boolean;
    /**
     * The NgControl associated with this input
     */
    protected control: NgControl | null;
    /**
     * The validity status of the related FormControl
     */
    isValid: boolean | null;
    /**
     * Every child should either call super(ngControl) or implement the logic for the input to bind the control to the FormControl.
     * @param ngControl the FormControl binded to this CVA
     */
    constructor(ngControl: NgControl | null);
    /**
     * A callback method that is invoked immediately after the default change detector has checked the directive's data-bound properties for the first time, and before any of the view or content children have been checked. It is invoked only once when the directive is instantiated.
     * In the case of the BaseInput class, this methods also subscribes to the onValueChange's subject as to register the debounce time.
     *
     * To use in any component inheriting the BaseInput Class, please call super.ngOnInit() at any point within the overriden ngOnInit() method.
     */
    ngOnInit(): void;
    /**
     * A callback method that is invoked immediately after Angular has completed initialization of a component's view. It is invoked only once when the view is instantiated.
     *
     * To use in any component inheriting the BaseInput Class, please call super.ngAfterViewInit() at any point within the overriden ngAfterViewInit() method.
     */
    ngAfterViewInit(): void;
    /**
     * A callback method that performs custom clean-up, invoked immediately before a directive, pipe, or service instance is destroyed.
     * In the case of the BaseInput class, this methods also unsubscribe to the onValueChange's subject as to avoid leaving a stray observable.
     *
     * To use in any component inheriting the BaseInput Class, please call super.ngOnDestroy() at any point within the overriden ngOnDestroy() method.
     */
    ngOnDestroy(): void;
    /**
     * A method that returns the input's value. If it's linked to a formcontrol returns the formcontrol's value otherwise the local value
     * @returns value any
     */
    getValue: () => any;
    /**
     * A method that can be used instead of onChange(value). It will pass the new value to an observable that will in turn add a debounce time then call the onchange function.
     *
     * In short, using this method instead of onChange will add a debounce time.
     * @param value The new value of the input
     * @returns the value observable
     */
    onValueChange: (value: any) => Subscription;
    writeValue(obj: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState?(isDisabled: boolean): void;
    protected updateValueAndValidity: () => void;
    /**
     * Despite it's name, this method returns a single validation error's display (even if there are multiple). And that is the first error found.
     * @returns display of the last error
     */
    protected getLastError: () => string | null;
    /**
     * Returns a boolean describing whether or not the control is required
     * @returns
     */
    protected isControlRequired: () => boolean;
    /**
     * Returns the current error status of the input.
     * @returns
     */
    protected hasError: () => boolean;
    private configureDebouncing;
    private configureTouchBehavior;
    private configureValidityReplication;
    private configureFormControl;
    private buildFormControl;
    protected doCallback: () => void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChrBaseInputComponent, [{ optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChrBaseInputComponent, "chr-base-input", never, { "label": { "alias": "label"; "required": false; }; "type": { "alias": "type"; "required": false; }; "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "span": { "alias": "span"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "iconCallback": { "alias": "iconCallback"; "required": false; }; "iconCallbackDisabled": { "alias": "iconCallbackDisabled"; "required": false; }; "iconTooltip": { "alias": "iconTooltip"; "required": false; }; "tooltip": { "alias": "tooltip"; "required": false; }; "debounceTime": { "alias": "debounceTime"; "required": false; }; "validations": { "alias": "validations"; "required": false; }; "standalone": { "alias": "standalone"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "base64": { "alias": "base64"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "siblings": { "alias": "siblings"; "required": false; }; }, { "valueChanges": "valueChanges"; }, never, never, true, never>;
}
