import { EventEmitter, ChangeDetectorRef, OnInit, ElementRef } from '@angular/core';
import { ValidatorFn } from '@angular/forms';
import { FormBuilder, FormGroup, FormControl } from '@angular/forms';
import { IControl } from '../models/controls';
import * as i0 from "@angular/core";
export interface IFormSection {
    title?: string;
    controls: IControl[];
}
export declare class ChrFormComponent implements OnInit {
    private builder;
    private changeDetector;
    private element;
    sections?: IFormSection[];
    controls?: IControl[];
    validators?: ValidatorFn | ValidatorFn[] | null;
    valid?: boolean;
    validChange: EventEmitter<boolean>;
    model: any;
    modelChange: EventEmitter<any>;
    formDataChange: EventEmitter<FormData>;
    disabled?: boolean;
    valuesChanges: EventEmitter<any>;
    submit?: Function;
    compact: boolean;
    debounceTime: number | null;
    formChange: EventEmitter<{
        [key: string]: any;
    }>;
    valueChanges: EventEmitter<{
        [name: string]: any;
    }>;
    tabDisplay: boolean;
    formControls: {
        [key: string]: FormControl;
    };
    /**
     * The related ReactiveForm of the form group. This is exposed to allow form extension and usage of custom form controls while still maintaining centralised validation and validity
     */
    form: FormGroup;
    formChanges: EventEmitter<FormGroup | null>;
    private values;
    private controlTypes;
    private flattenedControls;
    private flattenedShownControl;
    private flattenedHiddenControls;
    initialized: boolean;
    constructor(builder: FormBuilder, changeDetector: ChangeDetectorRef, element: ElementRef);
    ngOnInit(): void;
    private initModel;
    private initValues;
    private initControls;
    private initListeners;
    private hasRegularFile;
    getEncType: () => string;
    /**
     * Methods that returns the FormControl for the given input. If no FormControl is found, return null.
     * @param name input's name
     * @returns the FormControl whose name matches the parameter
     */
    getControl: (name: string) => import("@angular/forms").AbstractControl<any, any> | null;
    /**
     * Focus the input for the user to start typing in.
     * @param name input's name
     */
    focus: (name: string) => void;
    /**
     * Returns the value of the input whose name matches the parameter input.
     * If no input name is provided, returns the value of the form.
     * @param input name of the input
     * @returns the value of the input
     */
    value: (input?: string) => any;
    /**
     * Returns the value of the input whose name matches the parameter input.
     * If no input name is provided, returns the value of the form.
     * @param input name of the input
     * @returns the value of the input
     */
    getValue: (input?: string) => any;
    /**
     * Returns the validity of the input.
     * If no input is provided, returns the validity of the form.
     * @param input name of the input
     * @returns
     */
    isValid: (input?: string) => boolean | undefined;
    /**
     * Update the value of a control WITHOUT triggering the modelChange event
     * @param key input key (control name)
     * @param value value to set
     */
    setValue: (key: string, value: any) => void;
    /**
     * Update the value of the form's model WITHOUT triggering the modelChange event
     * @param model the model to set
     */
    set: (model: any) => void;
    /**
     * Updates the value of a control. This WILL trigger the modelChange event
     * @param key input key (control name)
     * @param value value to set
     */
    patchValue: (key: string, value: any) => void;
    /**
     * Updates the value of the form's model. This WILL trigger the modelChange event once for each input
     * @param model model to set
     */
    patch: (model: any) => void;
    /**
     * Methods that checks the validity of each input of the form and updates their status. If the markAsTouched parameter si set to true, it will also mark the inputs as touched
     * so that the validation errors may be displayed to the user.
     * @param markAsTouched Boolean that describes whether or not the inputs of the form will be marked as touched.
     */
    checkValidity: (markAsTouched?: boolean) => void;
    /**
     * Here for compatibility. Same thing as checkValidity.
     */
    updateValueAndValidity: (markAsTouched?: boolean) => void;
    /**
     * Resets the form.
     */
    reset: () => void;
    toFormData: () => FormData;
    protected get: (control: IControl) => import("@angular/forms").AbstractControl<any, any> | null;
    private setValue$;
    private setModel$;
    /**
     * Triggers the submit method and pass the local values as its parameters. The local values will contain the values of every input. Not just those that match de model's property (ex: like those provided by the modelChanges event).
     */
    doSubmit: () => void;
    protected log: (el: any) => void;
    protected initializeControl: (control: IControl, formControl: FormControl) => void;
    alert: (s: string) => void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChrFormComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChrFormComponent, "app-chr-form", never, { "sections": { "alias": "sections"; "required": false; }; "controls": { "alias": "controls"; "required": false; }; "validators": { "alias": "validators"; "required": false; }; "valid": { "alias": "valid"; "required": false; }; "model": { "alias": "model"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "submit": { "alias": "submit"; "required": false; }; "compact": { "alias": "compact"; "required": false; }; "debounceTime": { "alias": "debounceTime"; "required": false; }; "tabDisplay": { "alias": "tabDisplay"; "required": false; }; "form": { "alias": "form"; "required": false; }; }, { "validChange": "validChange"; "modelChange": "modelChange"; "formDataChange": "formDataChange"; "valuesChanges": "valuesChanges"; "formChange": "formChange"; "valueChanges": "valueChanges"; "formChanges": "formChanges"; }, never, never, true, never>;
}
