import { OnInit, OnDestroy } from '@angular/core';
import { ControlValueAccessor, NgControl } from '@angular/forms';
import { MatAutocomplete } from '@angular/material/autocomplete';
import { Observable, Subject } from 'rxjs';
import { ChrBaseInputComponent } from '../chr-form/chr-base-input/chr-base-input.component';
import * as i0 from "@angular/core";
export interface IInputSearchFilter {
    display: string;
    callback?: Function;
    tooltip?: string;
}
export declare class ChrSearchSelectComponent extends ChrBaseInputComponent implements ControlValueAccessor, OnInit, OnDestroy {
    predicate: boolean;
    filteredModelOptions?: Observable<any>;
    private values;
    autocomplete: MatAutocomplete;
    placeholder?: string;
    data: any[] | null;
    display?: (entry: any) => string;
    filters?: IInputSearchFilter[];
    /**
     * Callback that will be called BEFORE the value is added with the selected value passed as parameter.
     * If this callback returns null, the entry will NOT be added.
     * This lets you update the value before it's added.
     */
    addCallback?: ((entry: any, subject: Subject<any>) => any | null | void) | null;
    private addSubject;
    /**
     * Indicate if the input accepts raw text or if the requires the selection to be made from the search list.
     * This defaults to false.
     * If there are neither data nor display function, this defaults to true.
     */
    acceptText: boolean | null;
    protected filterIndex: number;
    protected overrideShowResults: boolean;
    constructor(ngControl: NgControl);
    ngOnInit(): void;
    /**
     * Reset the input's text and sets the value to null as to invalidate the input
     */
    protected reset: () => void;
    /**
     * Set's the input's text's value and set the value to null as to invalidate the input
     * @param input text input
     */
    protected inputChange: (input: string) => void;
    /**
     * Returns the model's textual value using the display function display passed as callback. If there is no display, returns the model's default string value.
     * @param model the data's entry for which we want the textual value
     * */
    protected getModelDisplay: (model: any) => any;
    /**
     * Start filtering the autocomplete's list based on the input's textual value
     */
    protected registerFilters: () => void;
    /**
     * Increments the filter and focus the filtered input. It also sets the value to null as to force the user to choose a filtered value.
     * @param input the input in which the user should type
     */
    protected increment: (input: any) => void;
    protected voidd: () => void;
    protected enableShowPanel: (input: any) => void;
    protected disableShowPanel: () => void;
    protected addFromText: (event: any) => void;
    private _filterModel;
    private _doFilterModelInt;
    private _doFilterModelString;
    private _filterValues;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChrSearchSelectComponent, [{ optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChrSearchSelectComponent, "app-chr-search-select, [app-chr-search-select]", never, { "placeholder": { "alias": "placeholder"; "required": false; }; "data": { "alias": "data"; "required": false; }; "display": { "alias": "display"; "required": false; }; "filters": { "alias": "filters"; "required": false; }; "addCallback": { "alias": "addCallback"; "required": false; }; "acceptText": { "alias": "acceptText"; "required": false; }; }, {}, never, ["*"], true, never>;
}
