import { ChangeDetectorRef, EventEmitter } from '@angular/core';
import { IAction } from '../chr-table/chr-table.component';
import { DataService } from '../services/data.service';
import { Color } from '../models/colors';
import { IControlValidation } from '../models/chr-validators/base-validator';
import * as i0 from "@angular/core";
export type TColumn = {
    /**
     * Nom de la colonne
     */
    display: string;
    /**
     * Sélecteur qui représente la propriété ciblée. Ex: 'obj.id'.
     */
    properties?: string;
    /**
     * Méthode callback qui sera appelée avec la valeur de la propriété cible.
     * Elle est utilisée pour apporter un traitement personnalisé à la valeur.
     * @param value valeur de la propriété cible
     * @returns
     */
    callback?: (value: any | null | undefined) => string;
    /**
     * Type de la colonne: lien, chips, input, date, default
     */
    type?: TColumnType;
    /**
     * Format de la date pour les colonnes de type date
     */
    format?: string;
    /**
     * Url de base pour les colonnes de type lien
     */
    url?: string;
    /**
     * Type d'input pour les colonnes de type input
     */
    inputType?: 'text' | 'number' | 'password' | 'date' | 'datetime' | 'file' | 'color' | 'toggle';
    /**
     * Règles de validations pour les colonnes de type input
     */
    validations?: IControlValidation[];
    /**
     * Chips disponibles pour les colonnes de type chips
     */
    chips?: {
        [key: string]: IChip;
    };
    /**
     * Méthode callback qui sera avec la valeur de la propriété cible.
     * Elle est utilisée comme clef pour sélectionner quel chips afficher
     * @param entry
     * @returns
     */
    chipsCallback?: (entry: any) => string;
};
export interface IChip {
    /**
     * Le text qui sera affiché dans le chips
     */
    display: string;
    /**
     * La couleur du background du chips
     */
    color: Color;
}
export type TColumnType = 'link' | 'chips' | 'input' | 'date' | 'default';
export declare class ChrDataTable {
    private dataService;
    private changeDetector;
    private _data;
    /**
     * Data to display.
     * @see If it's piped with | Async, please note that the input column may not work as expected
     */
    get data(): any[] | null;
    set data(value: any[] | null);
    /**
     * Whether or not the table will show a column with a checkbox to select entries. Default is false
     */
    selectable: boolean;
    /**
     * The selected entries
     */
    selection: any[];
    /**
     * The selected entries change event. This will be triggered on each selection and contain the full array of selected entries
     */
    selectionChange: EventEmitter<any[]>;
    /**
     * The table's action column definition
     */
    actions?: IAction[];
    /**
     * Wheter or not the current sort is ascendant. Default is true
     */
    isAsc: boolean;
    isAscChange: EventEmitter<boolean>;
    /**
     * The property by which the data will be sorted
     */
    sortBy?: string;
    sortByChange: EventEmitter<string>;
    /**
     * The page size for the table. Default is 20
     */
    pageSize: number;
    pageSizeChange: EventEmitter<number>;
    /**
     * The current page of the table. Default is 1
     */
    currentPage: number;
    currentPageChange: EventEmitter<number>;
    /**
     * The ID of the table. It's used to persist page size and currentpage when the user change pages
     */
    id?: string;
    /**
     * The color to use for the table's header
     */
    color?: Color;
    /**
     * The table's columns definitions
     */
    columns: TColumn[];
    constructor(dataService: DataService, changeDetector: ChangeDetectorRef);
    ngOnInit(): void;
    protected emitIsAsc(isAsc: any): void;
    protected emitSortBy(sortBy: any): void;
    protected emitPageSize(pageSize: any): void;
    protected emitCurrentPage(currentPage: any): void;
    protected getNestedProperty(obj: any, path?: string): any;
    protected select: (entry: any | any[], event: MouseEvent) => void;
    getSelection: () => any[];
    setSelection: (data: any[]) => void;
    protected contains: (entry: any) => boolean;
    updateModel: (entry: any, properties: string, value: {
        key: any;
    }) => void;
    protected getTextColor: (color?: Color) => string;
    protected getBackgroundColor: (color?: Color) => string;
    protected getContrastTextColor: (color?: Color) => string;
    protected getBorderColor: (color?: Color) => string;
    protected sort: (properties?: string) => void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChrDataTable, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChrDataTable, "chr-table", never, { "data": { "alias": "data"; "required": false; }; "selectable": { "alias": "selectable"; "required": false; }; "selection": { "alias": "selection"; "required": false; }; "actions": { "alias": "actions"; "required": false; }; "isAsc": { "alias": "isAsc"; "required": false; }; "sortBy": { "alias": "sortBy"; "required": false; }; "pageSize": { "alias": "pageSize"; "required": false; }; "currentPage": { "alias": "currentPage"; "required": false; }; "id": { "alias": "id"; "required": false; }; "color": { "alias": "color"; "required": false; }; "columns": { "alias": "columns"; "required": false; }; }, { "selectionChange": "selectionChange"; "isAscChange": "isAscChange"; "sortByChange": "sortByChange"; "pageSizeChange": "pageSizeChange"; "currentPageChange": "currentPageChange"; }, never, never, true, never>;
}
